@@ -155,6 +155,39 @@ class StfClient(Logger):
         device['owner'] = None
         self.logger.info(f'{serial}: released')
 
+    def list_devices(self, requirements: dict, fields: str = "") -> list:
+        """
+        Get list of devices filtered by given requirements and optional extra fields
+        :param requirements: filter dictionary
+        :param fields: extra fields to include
+        :return: list of objects that represent devices
+        """
+        req_keys = list(requirements.keys())
+        req_keys.extend(['present', 'ready', 'using', 'owner'])
+        req_keys.extend([
+            'serial', 'manufacturer', 'model',
+            'platform', 'sdk', 'version', 'note', 'group.name'
+        ])
+        req_keys.extend(fields.split(','))
+        fields = uniq(req_keys)
+
+        predicate = requirements.copy()
+
+        predicate.update(
+            dict(
+                present=True,
+                ready=True,
+                using=False,
+                owner=None)
+        )
+
+        self.logger.debug(
+            f"Find devices with requirements: {json.dumps(requirements)}, using fields: {','.join(fields)}")
+
+        devices = self.get_devices(fields=fields)
+
+        return filter_(devices, predicate)
+
     def find_and_allocate(self, requirements: dict,
                           timeout_seconds: int = DEFAULT_ALLOCATION_TIMEOUT_SECONDS,
                           shuffle: bool = True) -> dict:
@@ -166,28 +199,7 @@ class StfClient(Logger):
         :return: device dictionary
         """
         NotConnectedError.invariant(self._client, 'Not connected')
-        req_keys = list(requirements.keys())
-        req_keys.extend(['present', 'ready', 'using', 'owner'])
-        req_keys.extend([
-            'serial', 'manufacturer', 'model',
-            'platform', 'sdk', 'version', 'note'
-        ])
-        fields = uniq(req_keys)
-
-        predicate = requirements.copy()
-        predicate.update(
-            dict(
-                present=True,
-                ready=True,
-                using=False,
-                owner=None)
-        )
-
-        self.logger.debug(f"Find devices with requirements: {json.dumps(requirements)}, using fields: {','.join(fields)}")
-
-        devices = self.get_devices(fields=fields)
-
-        suitable_devices = filter_(devices, predicate)
+        suitable_devices = self.list_devices(requirements=requirements)
         DeviceNotFound.invariant(len(suitable_devices), 'no suitable devices found')
         if shuffle:
             random.shuffle(suitable_devices)
